@@ -4,7 +4,7 @@ from .posTag import PosTag
 TID_OBj = TokenIden()
 DTK_OBj = DictToken()
 PS_OBj = PmSeg()
-def get_ps(tid_cls=TID_OBj,dtk_cls=DTK_OBj,ps_cls=PS_OBj,textInput="ทดสอบ"):
+def get_ps(textInput="ทดสอบ",tid_cls=TID_OBj,dtk_cls=DTK_OBj,ps_cls=PS_OBj):
     if ps_cls.status_cls() == False:
         ps_cls.init_cls()
     tokenIdenList = tid_cls.tagTokenIden(textInput)
